@@ -238,6 +238,7 @@ private Q_SLOTS:
 
     void textDocumentCreated( KDevelop::IDocument*);
     void viewCreated(KTextEditor::Document*, KTextEditor::View*);
+    void viewDestroyed(QObject* obj);
 
 private:
     VariablesRoot* m_universe;
@@ -246,6 +247,8 @@ private:
 
     friend class VariableProvider;
     VariableProvider m_textHintProvider;
+
+    QVector<KTextEditor::View*> m_textHintProvidedViews;
 };
 
 }
