@@ -133,13 +133,12 @@ QValidator::State ProjectItemValidator::validate(QString& input, int& pos) const
     {
         // Check for a project whose name beings with the input
         QString first = path.first();
-        foreach( KDevelop::IProject* project, KDevelop::ICore::self()->projectController()->projects() )
-        {
-            if( project->name().startsWith( first, Qt::CaseInsensitive ) )
-            {
-                state = QValidator::Intermediate;
-                break;
-            }
+        const auto projects = KDevelop::ICore::self()->projectController()->projects();
+        bool matchesAnyName = std::any_of(projects.begin(), projects.end(), [&](KDevelop::IProject* project) {
+            return (project->name().startsWith(first, Qt::CaseInsensitive));
+        });
+        if (matchesAnyName) {
+            state = QValidator::Intermediate;
         }
     }
     return state;
@@ -161,8 +160,10 @@ public:
 
 ProjectItemLineEdit::ProjectItemLineEdit(QWidget* parent)
     : QLineEdit(parent),
-      d(new ProjectItemLineEditPrivate(this))
+      d_ptr(new ProjectItemLineEditPrivate(this))
 {
+    Q_D(ProjectItemLineEdit);
+
     setCompleter(d->completer);
     setValidator(d->validator);
     setPlaceholderText( i18n("Enter the path to an item from the projects tree" ) );
@@ -186,6 +187,8 @@ void ProjectItemLineEdit::showCtxMenu(const QPoint& p)
 
 bool ProjectItemLineEdit::selectItemDialog()
 {
+    Q_D(ProjectItemLineEdit);
+
     KDevelop::ProjectModel* model=KDevelop::ICore::self()->projectController()->projectModel();
 
     QDialog dialog;
@@ -193,8 +196,8 @@ bool ProjectItemLineEdit::selectItemDialog()
 
     auto mainLayout = new QVBoxLayout(&dialog);
 
-    QTreeView* view = new QTreeView(&dialog);
-    ProjectProxyModel* proxymodel = new ProjectProxyModel(view);
+    auto* view = new QTreeView(&dialog);
+    auto* proxymodel = new ProjectProxyModel(view);
     proxymodel->setSourceModel(model);
     view->header()->hide();
     view->setModel(proxymodel);
@@ -229,16 +232,22 @@ bool ProjectItemLineEdit::selectItemDialog()
 
 void ProjectItemLineEdit::setItemPath(const QStringList& list)
 {
+    Q_D(ProjectItemLineEdit);
+
     setText(KDevelop::joinWithEscaping(removeProjectBasePath(list, d->base), sep, escape));
 }
 
 QStringList ProjectItemLineEdit::itemPath() const
 {
+    Q_D(const ProjectItemLineEdit);
+
     return joinProjectBasePath(KDevelop::splitWithEscaping(text(), sep, escape), d->base);
 }
 
 void ProjectItemLineEdit::setBaseItem(KDevelop::ProjectBaseItem* item)
 {
+    Q_D(ProjectItemLineEdit);
+
     d->base = item;
     d->validator->setBaseItem(d->base);
     d->completer->setBaseItem(d->base);
@@ -246,6 +255,8 @@ void ProjectItemLineEdit::setBaseItem(KDevelop::ProjectBaseItem* item)
 
 KDevelop::ProjectBaseItem* ProjectItemLineEdit::baseItem() const
 {
+    Q_D(const ProjectItemLineEdit);
+
     return d->base;
 }
 
@@ -257,6 +268,8 @@ KDevelop::ProjectBaseItem* ProjectItemLineEdit::currentItem() const
 
 void ProjectItemLineEdit::setSuggestion(KDevelop::IProject* project)
 {
+    Q_D(ProjectItemLineEdit);
+
     d->suggestion = project;
 }
 
