@@ -63,16 +63,13 @@ IdealController::IdealController(Sublime::MainWindow* mainWindow):
 
     m_docks = qobject_cast<KActionMenu*>(mainWindow->action("docks_submenu"));
 
-    m_showLeftDock = qobject_cast<QAction*>(m_mainWindow->action("show_left_dock"));
-    m_showRightDock = qobject_cast<QAction*>(m_mainWindow->action("show_right_dock"));
-    m_showBottomDock = qobject_cast<QAction*>(m_mainWindow->action("show_bottom_dock"));
+    m_showLeftDock = m_mainWindow->action("show_left_dock");
+    m_showRightDock = m_mainWindow->action("show_right_dock");
+    m_showBottomDock = m_mainWindow->action("show_bottom_dock");
 
     // the 'show top dock' action got removed (IOW, it's never created)
     // (let's keep this code around if we ever want to reintroduce the feature...
-    auto action = m_mainWindow->action("show_top_dock");
-    if (action) {
-        m_showTopDock = qobject_cast<QAction*>(action);
-    }
+    m_showTopDock = m_mainWindow->action("show_top_dock");
 
     connect(m_mainWindow, &MainWindow::settingsLoaded, this, &IdealController::loadSettings);
 
@@ -80,7 +77,7 @@ IdealController::IdealController(Sublime::MainWindow* mainWindow):
 
 void IdealController::addView(Qt::DockWidgetArea area, View* view)
 {
-    IdealDockWidget *dock = new IdealDockWidget(this, m_mainWindow);
+    auto *dock = new IdealDockWidget(this, m_mainWindow);
     // dock object name is used to store tool view settings
     QString dockObjectName = view->document()->title();
     // support different configuration for same docks opened in different areas
@@ -104,7 +101,7 @@ void IdealController::addView(Qt::DockWidgetArea area, View* view)
       dock->setWidget(w);
     } else {
       QMainWindow *toolView = new QMainWindow();
-      QToolBar *toolBar = new QToolBar(toolView);
+      auto *toolBar = new QToolBar(toolView);
       int iconSize = m_mainWindow->style()->pixelMetric(QStyle::PM_SmallIconSize);
       toolBar->setIconSize(QSize(iconSize, iconSize));
       toolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
@@ -154,7 +151,7 @@ void IdealController::dockLocationChanged(Qt::DockWidgetArea area)
         return;
     }
 
-    IdealDockWidget *dock = qobject_cast<IdealDockWidget*>(sender());
+    auto *dock = qobject_cast<IdealDockWidget*>(sender());
     View *view = dock->view();
     QAction* action = m_view_to_action.value(view);
 
@@ -229,7 +226,7 @@ IdealButtonBarWidget* IdealController::barForDockArea(Qt::DockWidgetArea area) c
 
 void IdealController::slotDockBarContextMenuRequested(const QPoint& position)
 {
-    IdealButtonBarWidget* bar = qobject_cast<IdealButtonBarWidget*>(sender());
+    auto* bar = qobject_cast<IdealButtonBarWidget*>(sender());
     Q_ASSERT(bar);
 
     emit dockBarContextMenuRequested(bar->area(), bar->mapToGlobal(position));
@@ -336,7 +333,7 @@ void IdealController::removeView(View* view, bool nondestructive)
     QAction* action = m_view_to_action.value(view);
 
     QWidget *viewParent = view->widget()->parentWidget();
-    IdealDockWidget *dock = qobject_cast<IdealDockWidget *>(viewParent);
+    auto *dock = qobject_cast<IdealDockWidget *>(viewParent);
     if (!dock) { // tool views with a toolbar live in a QMainWindow which lives in a Dock
         Q_ASSERT(qobject_cast<QMainWindow*>(viewParent));
         viewParent = viewParent->parentWidget();
@@ -385,7 +382,8 @@ void IdealController::showRightDock(bool show)
 
 void IdealController::hideDocks(IdealButtonBarWidget *bar)
 {
-    foreach (QAction *action, bar->actions()) {
+    const auto barActions = bar->actions();
+    for (QAction* action : barActions) {
         if (action->isChecked())
             action->setChecked(false);
     }
@@ -432,7 +430,7 @@ IdealDockWidget* IdealController::currentDockWidget() const
     QWidget *w = m_mainWindow->focusWidget();
     while (true) {
         if (!w) break;
-        IdealDockWidget *dockCandidate = qobject_cast<IdealDockWidget*>(w);
+        auto *dockCandidate = qobject_cast<IdealDockWidget*>(w);
         if (dockCandidate)
             return dockCandidate;
 
