@@ -32,188 +32,223 @@ unsigned int extractor_div_with = 0;
 #include <tests/testcore.h>
 #include <tests/autotestshell.h>
 
-struct TestItem {
-    explicit TestItem(uint _value = 0) : value(_value) {
+struct TestItem
+{
+    explicit TestItem(uint _value = 0) : value(_value)
+    {
     }
     uint value;
     int leftChild = -1;
     int rightChild = -1;
-    bool operator==(const TestItem& rhs) const {
+    bool operator==(const TestItem& rhs) const
+    {
         return value == rhs.value;
     }
 
-    bool operator<(const TestItem& item) const {
+    bool operator<(const TestItem& item) const
+    {
         return value < item.value;
     }
 };
 
-struct TestItemConversion {
-    static uint toIndex(const TestItem& item) {
+struct TestItemConversion
+{
+    static uint toIndex(const TestItem& item)
+    {
         return item.value;
     }
-    static TestItem toItem(uint index) {
+    static TestItem toItem(uint index)
+    {
         return TestItem(index);
     }
 };
 
-struct Extractor{
-    static TestItem extract(const TestItem& item) {
-        return TestItem(item.value/extractor_div_with);
+struct Extractor
+{
+    static TestItem extract(const TestItem& item)
+    {
+        return TestItem(item.value / extractor_div_with);
     }
 };
 
+clock_t std_insertion = 0, std_removal = 0, std_contains = 0, std_iteration = 0, emb_insertion = 0, emb_removal = 0,
+        emb_contains = 0, emb_iteration = 0;
 
-clock_t std_insertion = 0, std_removal = 0, std_contains = 0, std_iteration = 0, emb_insertion = 0, emb_removal = 0, emb_contains = 0, emb_iteration = 0;
-
-QString toString(const std::set<uint>& set) {
+QString toString(const std::set<uint>& set)
+{
     QString ret;
-    for(std::set<uint>::const_iterator it = set.begin(); it != set.end(); ++it)
+    for (auto it = set.begin(); it != set.end(); ++it)
         ret += QStringLiteral("%1 ").arg(*it);
+
     return ret;
 }
 
-bool operator==(const std::set<uint>& a, const std::set<uint>& b) {
-    if(a.size() != b.size()) {
+bool operator==(const std::set<uint>& a, const std::set<uint>& b)
+{
+    if (a.size() != b.size()) {
         qDebug() << "size mismatch" << toString(a) << ": " << toString(b);
         return false;
     }
-    std::set<uint>::const_iterator aIt = a.begin();
-    std::set<uint>::const_iterator bIt = b.begin();
-    for(; aIt != a.end(); ++aIt, ++bIt)
-        if(*aIt != *bIt) {
+    auto aIt = a.begin();
+    auto bIt = b.begin();
+    for (; aIt != a.end(); ++aIt, ++bIt)
+        if (*aIt != *bIt) {
             qDebug() << "mismatch" << toString(a) << ": " << toString(b);
             return false;
         }
+
     return true;
 }
 
-    struct TestItemHandler {
-        public:
-        static int rightChild(const TestItem& m_data) {
-            return m_data.rightChild;
-        }
-        static int leftChild(const TestItem& m_data) {
-            return m_data.leftChild;
-        }
-        static void setLeftChild(TestItem& m_data, int child) {
-            m_data.leftChild = child;
-        }
-        static void setRightChild(TestItem& m_data, int child) {
-            m_data.rightChild = child;
-        }
-        //Copies this item into the given one
-        static void copyTo(const TestItem& m_data, TestItem& data) {
-            data = m_data;
-        }
-        static void createFreeItem(TestItem& data) {
-            data = TestItem();
-        }
-        static inline bool isFree(const TestItem& m_data) {
-            return !m_data.value;
-        }
+struct TestItemHandler
+{
+public:
+    static int rightChild(const TestItem& m_data)
+    {
+        return m_data.rightChild;
+    }
+    static int leftChild(const TestItem& m_data)
+    {
+        return m_data.leftChild;
+    }
+    static void setLeftChild(TestItem& m_data, int child)
+    {
+        m_data.leftChild = child;
+    }
+    static void setRightChild(TestItem& m_data, int child)
+    {
+        m_data.rightChild = child;
+    }
+    //Copies this item into the given one
+    static void copyTo(const TestItem& m_data, TestItem& data)
+    {
+        data = m_data;
+    }
+    static void createFreeItem(TestItem& data)
+    {
+        data = TestItem();
+    }
+    static inline bool isFree(const TestItem& m_data)
+    {
+        return !m_data.value;
+    }
 
-        static const TestItem& data(const TestItem& m_data) {
-            return m_data;
-        }
+    static const TestItem& data(const TestItem& m_data)
+    {
+        return m_data;
+    }
 
-        inline static bool equals(const TestItem& m_data, const TestItem& rhs) {
-            return m_data.value == rhs.value;
-        }
-    };
+    inline static bool equals(const TestItem& m_data, const TestItem& rhs)
+    {
+        return m_data.value == rhs.value;
+    }
+};
 
-    class TestItemBasedSet {
-        public:
-            TestItemBasedSet() {
+class TestItemBasedSet
+{
+public:
+    TestItemBasedSet()
+    {
+    }
+
+    void insert(uint i)
+    {
+        TestItem item(i);
+        KDevelop::EmbeddedTreeAddItem<TestItem, TestItemHandler> add(data.data(), data.size(), m_centralFree, item);
+
+        if (( int )add.newItemCount() != ( int )data.size()) {
+            QVector<TestItem> newData;
+            newData.resize(add.newItemCount());
+            add.transferData(newData.data(), newData.size());
+            data = newData;
+        }
+    }
+
+    bool contains(uint item)
+    {
+        KDevelop::EmbeddedTreeAlgorithms<TestItem, TestItemHandler> alg(data.data(), data.size(), m_centralFree);
+        return alg.indexOf(TestItem(item)) != -1;
+    }
+
+    void remove(uint i)
+    {
+        TestItem item(i);
+        KDevelop::EmbeddedTreeRemoveItem<TestItem, TestItemHandler> remove(data.data(), data.size(), m_centralFree,
+            item);
+
+        if (( int )remove.newItemCount() != ( int )data.size()) {
+            QVector<TestItem> newData;
+            newData.resize(remove.newItemCount());
+            remove.transferData(newData.data(), newData.size());
+            data = newData;
+        }
+    }
+
+    std::set<uint> toSet() const
+    {
+        std::set<uint> ret;
+
+        for (int a = 0; a < data.size(); ++a)
+            if (data[a].value)
+                ret.insert(data[a].value);
+
+        return ret;
+    }
+
+    void verify()
+    {
+        //1. verify order
+        uint last = 0;
+        uint freeCount = 0;
+        for (int a = 0; a < data.size(); ++a) {
+            if (data[a].value) {
+                QVERIFY(last < data[a].value);
+                last = data[a].value;
+            } else {
+                ++freeCount;
             }
+        }
 
-            void insert(uint i) {
-                TestItem item(i);
-                KDevelop::EmbeddedTreeAddItem<TestItem, TestItemHandler> add(data.data(), data.size(), m_centralFree, item);
+        KDevelop::EmbeddedTreeAlgorithms<TestItem, TestItemHandler> algorithms(data.data(), data.size(), m_centralFree);
+        uint countFree = algorithms.countFreeItems();
+        QCOMPARE(freeCount, countFree);
+        algorithms.verifyTreeConsistent();
+    }
 
-                if((int)add.newItemCount() != (int)data.size()) {
-                    QVector<TestItem> newData;
-                    newData.resize(add.newItemCount());
-                    add.transferData(newData.data(), newData.size());
-                    data = newData;
-                }
+    uint getItem(uint number) const
+    {
+        Q_ASSERT(number < ( uint )data.size());
+        uint ret = 0;
+        uint size = ( uint )data.size();
+        uint current = 0;
+        for (uint a = 0; a < size; ++a) {
+            if (data[a].value) {
+                //Only count the non-free items
+                if (current == number)
+                    ret = data[a].value;
+                ++current;
+            } else {
+                //This is a free item
             }
+        }
 
-            bool contains(uint item) {
-                KDevelop::EmbeddedTreeAlgorithms<TestItem, TestItemHandler> alg(data.data(), data.size(), m_centralFree);
-                return alg.indexOf(TestItem(item)) != -1;
-            }
+        return ret;
+    }
 
-            void remove(uint i) {
-                TestItem item(i);
-                KDevelop::EmbeddedTreeRemoveItem<TestItem, TestItemHandler> remove(data.data(), data.size(), m_centralFree, item);
+private:
+    int m_centralFree = -1;
+    QVector<TestItem> data;
+};
 
-                if((int)remove.newItemCount() != (int)data.size()) {
-                    QVector<TestItem> newData;
-                    newData.resize(remove.newItemCount());
-                    remove.transferData(newData.data(), newData.size());
-                    data = newData;
-                }
-            }
-
-            std::set<uint> toSet() const {
-                std::set<uint> ret;
-
-                for(int a = 0; a < data.size(); ++a)
-                    if(data[a].value)
-                        ret.insert(data[a].value);
-
-                return ret;
-            }
-
-            void verify() {
-                //1. verify order
-                uint last = 0;
-                uint freeCount = 0;
-                for(int a = 0; a < data.size(); ++a) {
-                    if(data[a].value) {
-                        QVERIFY(last < data[a].value);
-                        last = data[a].value;
-                    }else{
-                        ++freeCount;
-                    }
-                }
-                KDevelop::EmbeddedTreeAlgorithms<TestItem, TestItemHandler> algorithms(data.data(), data.size(), m_centralFree);
-                uint countFree = algorithms.countFreeItems();
-                QCOMPARE(freeCount, countFree);
-                algorithms.verifyTreeConsistent();
-            }
-
-            uint getItem(uint number) const {
-                Q_ASSERT(number < (uint)data.size());
-                uint ret = 0;
-                uint size = (uint)data.size();
-                uint current = 0;
-                for(uint a = 0; a < size; ++a) {
-                    if(data[a].value) {
-                        //Only count the non-free items
-                        if(current == number)
-                            ret = data[a].value;
-                        ++current;
-                    }else{
-                        //This is a free item
-                    }
-                }
-                return ret;
-            }
-
-        private:
-            int m_centralFree = -1;
-            QVector<TestItem> data;
-    };
-
-
-class TestSet {
-    public:
-    void add(uint i) {
-        if(realSet.find(i) != realSet.end()) {
+class TestSet
+{
+public:
+    void add(uint i)
+    {
+        if (realSet.find(i) != realSet.end()) {
             QVERIFY(set.contains(i));
             return;
-        }else{
+        } else {
             QVERIFY(!set.contains(i));
         }
         clock_t start = clock();
@@ -237,10 +272,11 @@ class TestSet {
         set.verify();
     }
 
-    void remove(uint i) {
-        if(realSet.find(i) != realSet.end()) {
+    void remove(uint i)
+    {
+        if (realSet.find(i) != realSet.end()) {
             QVERIFY(set.contains(i));
-        }else{
+        } else {
             QVERIFY(!set.contains(i));
             return;
         }
@@ -252,26 +288,28 @@ class TestSet {
         realSet.erase(i);
         std_removal += clock() - start;
 
-
         QVERIFY(!set.contains(i));
     }
 
-    uint size() const {
+    uint size() const
+    {
         return realSet.size();
     }
 
-    uint getItem(uint number) const {
+    uint getItem(uint number) const
+    {
         Q_ASSERT(number < size());
         uint current = 0;
         uint ret = 0;
 
         clock_t start = clock();
-        for(std::set<uint>::const_iterator it = realSet.begin(); it != realSet.end(); ++it) {
-            if(current == number) {
+        for (auto it = realSet.begin(); it != realSet.end(); ++it) {
+            if (current == number) {
                 ret = *it;
             }
             ++current;
         }
+
         std_iteration += clock() - start;
 
         start = clock();
@@ -282,79 +320,98 @@ class TestSet {
         return ret;
     }
 
-    void verify() {
+    void verify()
+    {
         QVERIFY(realSet == set.toSet());
         set.verify();
     }
-    private:
+
+private:
     std::set<uint> realSet;
     TestItemBasedSet set;
 };
 
-float toSeconds(clock_t time) {
-    return ((float)time) / CLOCKS_PER_SEC;
+float toSeconds(clock_t time)
+{
+    return (( float )time) / CLOCKS_PER_SEC;
 }
 
-struct StaticRepository {
-    static Utils::BasicSetRepository* repository() {
+struct StaticRepository
+{
+    static Utils::BasicSetRepository* repository()
+    {
         static Utils::BasicSetRepository repository(QStringLiteral("test repository"));
         return &repository;
     }
 };
 
-struct UintSetVisitor {
+struct UintSetVisitor
+{
     std::set<uint>& s;
-    explicit UintSetVisitor(std::set<uint>& _s) : s(_s) {
+    explicit UintSetVisitor(std::set<uint>& _s) : s(_s)
+    {
     }
 
-    inline bool operator() (const TestItem& item) {
+    inline bool operator()(const TestItem& item)
+    {
         s.insert(item.value);
         return true;
     }
 };
 
-struct NothingDoVisitor {
-    inline bool operator() (const TestItem& item) {
+struct NothingDoVisitor
+{
+    inline bool operator()(const TestItem& item)
+    {
         Q_UNUSED(item);
         return true;
     }
 };
 
-class TestEmbeddedFreeTree : public QObject {
-  Q_OBJECT
-  private Q_SLOTS:
-    void initTestCase() {
+class TestEmbeddedFreeTree : public QObject
+{
+    Q_OBJECT
+
+private Q_SLOTS:
+    void initTestCase()
+    {
         KDevelop::AutoTestShell::init();
         KDevelop::TestCore::initialize(KDevelop::Core::NoUi);
     }
-    void cleanupTestCase() {
+    void cleanupTestCase()
+    {
         KDevelop::TestCore::shutdown();
     }
-    void randomizedTest() {
+    void randomizedTest()
+    {
         const int cycles = 10000;
         const int valueRange = 1000;
         const int removeProbability = 40; //Percent
 
         TestSet set;
         srand(time(nullptr));
-        for(int a = 0; a < cycles; ++a) {
-            if(a % (cycles / 10) == 0) {
+        for (int a = 0; a < cycles; ++a) {
+            if (a % (cycles / 10) == 0) {
                 qDebug() << "cycle" << a;
             }
 
             bool remove = (rand() % 100) < removeProbability;
-            if(remove && set.size()) {
+            if (remove && set.size()) {
                 set.remove(set.getItem(rand() % set.size()));
-            }else{
+            } else {
                 int value = (rand() % valueRange) + 1;
                 set.add(value);
             }
             set.verify();
         }
-        qDebug() << "Performance embedded list: insertion:" << toSeconds(emb_insertion) << "removal:" << toSeconds(emb_removal) << "contains:" << toSeconds(emb_contains) << "iteration:" << toSeconds(emb_iteration);
-        qDebug() << "Performance std::set: insertion:" << toSeconds(std_insertion) << "removal:" << toSeconds(std_removal) << "contains:" << toSeconds(std_contains) << "iteration:" << toSeconds(std_iteration);
+
+        qDebug() << "Performance embedded list: insertion:" << toSeconds(emb_insertion) << "removal:" << toSeconds(
+            emb_removal) << "contains:" << toSeconds(emb_contains) << "iteration:" << toSeconds(emb_iteration);
+        qDebug() << "Performance std::set: insertion:" << toSeconds(std_insertion) << "removal:" << toSeconds(
+            std_removal) << "contains:" << toSeconds(std_contains) << "iteration:" << toSeconds(std_iteration);
     }
-    void sequentialTest() {
+    void sequentialTest()
+    {
         TestSet set;
         set.add(5);
         set.verify();
@@ -422,7 +479,8 @@ class TestEmbeddedFreeTree : public QObject {
         set.verify();
     }
 
-    void testFiltering() {
+    void testFiltering()
+    {
         clock_t stdTime = 0;
         clock_t algoTime = 0;
         clock_t treeAlgoTime = 0;
@@ -432,7 +490,7 @@ class TestEmbeddedFreeTree : public QObject {
         clock_t insertionAlgoTime = 0;
         clock_t insertionTreeAlgoTime = 0;
 
-        typedef Utils::StorableSet<TestItem, TestItemConversion, StaticRepository> RepositorySet;
+        using RepositorySet = Utils::StorableSet<TestItem, TestItemConversion, StaticRepository>;
 
         const uint cycles = 3000;
         const uint setSize = 1500;
@@ -440,7 +498,7 @@ class TestEmbeddedFreeTree : public QObject {
         uint totalItems = 0, totalFilteredItems = 0;
 
         srand(time(nullptr));
-        for(uint a = 0; a < cycles; ++a) {
+        for (uint a = 0; a < cycles; ++a) {
             KDevelop::ConvenientFreeListSet<TestItem, TestItemHandler> set1;
             std::set<uint> testSet1;
 
@@ -448,20 +506,20 @@ class TestEmbeddedFreeTree : public QObject {
             std::set<uint> testSet2;
             RepositorySet repSet2;
 
-            if(a % (cycles / 10) == 0) {
+            if (a % (cycles / 10) == 0) {
                 qDebug() << "cycle" << a;
             }
 
             //Build the sets
             extractor_div_with = (rand() % 10) + 1;
-            for(uint a = 0; a < setSize; ++a) {
+            for (uint a = 0; a < setSize; ++a) {
                 uint value = rand() % 3000;
-                uint divValue = value/extractor_div_with;
-                if(!divValue)
+                uint divValue = value / extractor_div_with;
+                if (!divValue)
                     continue;
 //                 qDebug() << "inserting" << value;
 
-                std::set<uint>::const_iterator it = testSet1.lower_bound(value);
+                auto it = testSet1.lower_bound(value);
                 int pos = set1.iterator().lowerBound(TestItem(value));
                 //This tests the upperBound functionality
                 if (pos != -1) {
@@ -471,14 +529,14 @@ class TestEmbeddedFreeTree : public QObject {
                     QVERIFY(it == testSet1.end());
                 }
 
-                if((rand() % 10) == 0) {
+                if ((rand() % 10) == 0) {
 
                     set1.insert(TestItem(value));
                     testSet1.insert(value);
                 }
 
                 //This is tuned so in the end, about 99% of all declarations are filtered out, like in the symbol table.
-                if((rand() % (extractor_div_with*100)) == 0) {
+                if ((rand() % (extractor_div_with * 100)) == 0) {
 
                     clock_t start = clock();
 
@@ -500,15 +558,15 @@ class TestEmbeddedFreeTree : public QObject {
             }
 
             std::set<uint> verifySet1;
-            for(KDevelop::ConvenientFreeListSet<TestItem, TestItemHandler>::Iterator it = set1.iterator(); it; ++it)
+            for (KDevelop::ConvenientFreeListSet<TestItem, TestItemHandler>::Iterator it = set1.iterator(); it; ++it)
                 verifySet1.insert(it->value);
 
             std::set<uint> verifySet2;
-            for(KDevelop::ConvenientFreeListSet<TestItem, TestItemHandler>::Iterator it = set2.iterator(); it; ++it)
+            for (KDevelop::ConvenientFreeListSet<TestItem, TestItemHandler>::Iterator it = set2.iterator(); it; ++it)
                 verifySet2.insert(it->value);
 
             std::set<uint> verifyRepSet2;
-            for(RepositorySet::Iterator it = repSet2.iterator(); it; ++it)
+            for (RepositorySet::Iterator it = repSet2.iterator(); it; ++it)
                 verifyRepSet2.insert((*it).value);
 
             QCOMPARE(verifySet1, testSet1);
@@ -524,8 +582,9 @@ class TestEmbeddedFreeTree : public QObject {
                 clock_t start = clock();
 
                 {
-                    KDevelop::ConvenientEmbeddedSetFilterIterator<TestItem, TestItemHandler, TestItem, TestItemHandler, Extractor> filterIterator(set1.iterator(), set2.iterator());
-                    while(filterIterator)
+                    KDevelop::ConvenientEmbeddedSetFilterIterator<TestItem, TestItemHandler, TestItem, TestItemHandler,
+                        Extractor> filterIterator(set1.iterator(), set2.iterator());
+                    while (filterIterator)
                         ++filterIterator;
 
                     algoTime += clock() - start;
@@ -534,8 +593,9 @@ class TestEmbeddedFreeTree : public QObject {
                 start = clock();
 
                 {
-                    KDevelop::ConvenientEmbeddedSetTreeFilterIterator<TestItem, TestItemHandler, TestItem, RepositorySet, Extractor> filterIterator(set1.iterator(), repSet2);
-                    while(filterIterator)
+                    KDevelop::ConvenientEmbeddedSetTreeFilterIterator<TestItem, TestItemHandler, TestItem,
+                        RepositorySet, Extractor> filterIterator(set1.iterator(), repSet2);
+                    while (filterIterator)
                         ++filterIterator;
 
                     treeAlgoTime += clock() - start;
@@ -545,16 +605,16 @@ class TestEmbeddedFreeTree : public QObject {
                     start = clock();
 
                     NothingDoVisitor v;
-                    KDevelop::ConvenientEmbeddedSetTreeFilterVisitor<TestItem, TestItemHandler, TestItem, RepositorySet, Extractor, NothingDoVisitor> visit(v, set1.iterator(), repSet2);
+                    KDevelop::ConvenientEmbeddedSetTreeFilterVisitor<TestItem, TestItemHandler, TestItem, RepositorySet,
+                        Extractor, NothingDoVisitor> visit(v, set1.iterator(), repSet2);
 
                     treeAlgoVisitorTime += clock() - start;
                 }
 
-
                 start = clock();
 
-                for(std::set<uint>::const_iterator it = testSet1.begin(); it != testSet1.end(); ++it) {
-                    if(testSet2.count((*it) / extractor_div_with) == 1) {
+                for (auto it = testSet1.begin(); it != testSet1.end(); ++it) {
+                    if (testSet2.count((*it) / extractor_div_with) == 1) {
                     }
                 }
 
@@ -562,33 +622,34 @@ class TestEmbeddedFreeTree : public QObject {
             }
 
             {
-                KDevelop::ConvenientEmbeddedSetFilterIterator<TestItem, TestItemHandler, TestItem, TestItemHandler, Extractor> filterIterator(set1.iterator(), set2.iterator());
-                while(filterIterator) {
+                KDevelop::ConvenientEmbeddedSetFilterIterator<TestItem, TestItemHandler, TestItem, TestItemHandler,
+                    Extractor> filterIterator(set1.iterator(), set2.iterator());
+                while (filterIterator) {
                     algoFiltered.insert(filterIterator->value);
                     ++filterIterator;
                 }
             }
             {
-                KDevelop::ConvenientEmbeddedSetTreeFilterIterator<TestItem, TestItemHandler, TestItem, RepositorySet, Extractor> filterIterator(set1.iterator(), repSet2);
-                while(filterIterator) {
+                KDevelop::ConvenientEmbeddedSetTreeFilterIterator<TestItem, TestItemHandler, TestItem, RepositorySet,
+                    Extractor> filterIterator(set1.iterator(), repSet2);
+                while (filterIterator) {
                     treeAlgoFiltered.insert((*filterIterator).value);
                     ++filterIterator;
                 }
             }
             {
                 UintSetVisitor v(treeAlgoVisitorFiltered);
-                KDevelop::ConvenientEmbeddedSetTreeFilterVisitor<TestItem, TestItemHandler, TestItem, RepositorySet, Extractor, UintSetVisitor> visit(v, set1.iterator(), repSet2);
+                KDevelop::ConvenientEmbeddedSetTreeFilterVisitor<TestItem, TestItemHandler, TestItem, RepositorySet,
+                    Extractor, UintSetVisitor> visit(v, set1.iterator(), repSet2);
             }
 
-
             totalItems += testSet1.size();
             totalFilteredItems += algoFiltered.size();
 
-
             std::set<uint> stdFiltered;
 
-            for(std::set<uint>::const_iterator it = testSet1.begin(); it != testSet1.end(); ++it) {
-                if(testSet2.count((*it) / extractor_div_with) == 1) {
+            for (auto it = testSet1.begin(); it != testSet1.end(); ++it) {
+                if (testSet2.count((*it) / extractor_div_with) == 1) {
                     stdFiltered.insert(*it);
                 }
             }
@@ -598,8 +659,15 @@ class TestEmbeddedFreeTree : public QObject {
             QCOMPARE(treeAlgoVisitorFiltered, stdFiltered);
 
         }
-        qDebug() << "Filtering performance: embedded-list filtering:" << toSeconds(algoTime) << "set-repository filtering:" << toSeconds(treeAlgoTime) << "set-repository visitor filtering:" << toSeconds(treeAlgoVisitorTime) << "std::set filtering:" << toSeconds(stdTime) << "Normal -> Embedded speedup ratio:" << (toSeconds(stdTime) / toSeconds(algoTime)) << "Normal -> Repository speedup ratio:" << (toSeconds(stdTime) / toSeconds(treeAlgoVisitorTime)) << "total processed items:" << totalItems << "total items after filtering:" << totalFilteredItems;
-        qDebug() << "Insertion: embedded-list:" << toSeconds(insertionAlgoTime) << "set-repository:" << toSeconds(insertionTreeAlgoTime) << "std::set:" << toSeconds(insertionStdTime);
+
+        qDebug() << "Filtering performance: embedded-list filtering:" << toSeconds(algoTime) <<
+        "set-repository filtering:" << toSeconds(treeAlgoTime) << "set-repository visitor filtering:" << toSeconds(
+            treeAlgoVisitorTime) << "std::set filtering:" << toSeconds(stdTime) <<
+        "Normal -> Embedded speedup ratio:" << (toSeconds(stdTime) / toSeconds(algoTime)) <<
+        "Normal -> Repository speedup ratio:" << (toSeconds(stdTime) / toSeconds(treeAlgoVisitorTime)) <<
+        "total processed items:" << totalItems << "total items after filtering:" << totalFilteredItems;
+        qDebug() << "Insertion: embedded-list:" << toSeconds(insertionAlgoTime) << "set-repository:" << toSeconds(
+            insertionTreeAlgoTime) << "std::set:" << toSeconds(insertionStdTime);
 
     }
 };
