@@ -20,6 +20,7 @@
 #include "test_assistants.h"
 
 #include "codegen/clangrefactoring.h"
+#include "codegen/adaptsignatureassistant.h"
 
 #include <QTest>
 #include <QLoggingCategory>
@@ -303,6 +304,18 @@ ProblemPointer findStaticAssistantProblem(const QVector<ProblemPointer>& problem
     return {};
 }
 
+template <typename T>
+ProblemPointer findProblemWithAssistant(const QVector<ProblemPointer>& problems)
+{
+    const auto problemIterator = std::find_if(problems.cbegin(), problems.cend(), [](const ProblemPointer& p) {
+        return dynamic_cast<const T*>(p->solutionAssistant().constData());
+    });
+    if (problemIterator != problems.cend())
+        return *problemIterator;
+
+    return {};
+}
+
 void TestAssistants::testRenameAssistant()
 {
     QFETCH(QString, fileContents);
@@ -315,8 +328,7 @@ void TestAssistants::testRenameAssistant()
 
     QFETCH(QString, oldDeclarationName);
     QFETCH(QList<StateChange>, stateChanges);
-    foreach(StateChange stateChange, stateChanges)
-    {
+    for (const StateChange& stateChange : qAsConst(stateChanges)) {
         testbed.changeDocument(Testbed::CppDoc, stateChange.range, stateChange.newText, true);
 
         DUChainReadLocker lock;
@@ -333,7 +345,7 @@ void TestAssistants::testRenameAssistant()
         } else {
             qWarning() << assistant.data() << stateChange.result;
             QVERIFY(assistant && assistant->actions().size());
-            RenameAction *r = qobject_cast<RenameAction*>(assistant->actions().first().data());
+            auto *r = qobject_cast<RenameAction*>(assistant->actions().first().data());
             QCOMPARE(r->oldDeclarationName(), oldDeclarationName);
             QCOMPARE(r->newDeclarationName(), stateChange.result);
         }
@@ -364,7 +376,7 @@ void TestAssistants::testRenameAssistantUndoRename()
     QVERIFY(assistant);
 
     QVERIFY(assistant->actions().size() > 0);
-    RenameAction *r = qobject_cast<RenameAction*>(assistant->actions().first().data());
+    auto *r = qobject_cast<RenameAction*>(assistant->actions().first().data());
     qWarning() << topCtx->problems() << assistant->actions().first().data() << assistant->actions().size();
     QVERIFY(r);
 
@@ -516,8 +528,7 @@ void TestAssistants::testSignatureAssistant()
     QExplicitlySharedDataPointer<IAssistant> assistant;
 
     QFETCH(QList<StateChange>, stateChanges);
-    foreach (StateChange stateChange, stateChanges)
-    {
+    for (const StateChange& stateChange : qAsConst(stateChanges)) {
         testbed.changeDocument(stateChange.document, stateChange.range, stateChange.newText, true);
 
         const auto document = testbed.document(stateChange.document);
@@ -528,7 +539,7 @@ void TestAssistants::testSignatureAssistant()
         auto topCtx = DUChain::self()->chainForDocument(document->url());
         QVERIFY(topCtx);
 
-        const auto problem = findStaticAssistantProblem(DUChainUtils::allProblemsForContext(topCtx));
+        const auto problem = findProblemWithAssistant<AdaptSignatureAssistant>(DUChainUtils::allProblemsForContext(topCtx));
         if (problem) {
             assistant = problem->solutionAssistant();
         }
@@ -798,3 +809,104 @@ void TestAssistants::testMoveIntoSource_data()
             << QStringLiteral("Class::Class() {}\n")
             << QualifiedIdentifier(QStringLiteral("Class::Class"));
 }
+
+void TestAssistants::testHeaderGuardAssistant()
+{
+    CodeRepresentation::setDiskChangesForbidden(false);
+
+    QFETCH(QString, filename);
+    QFETCH(QString, code);
+    QFETCH(QString, pragmaExpected);
+    QFETCH(QString, macroExpected);
+
+    TestFile pragmaFile (code, QStringLiteral("h"));
+    TestFile macroFile (code, QStringLiteral("h"), filename);
+
+    QExplicitlySharedDataPointer<IAssistant> pragmaAssistant;
+    QExplicitlySharedDataPointer<IAssistant> macroAssistant;
+
+    pragmaFile.parse(TopDUContext::Empty);
+    macroFile.parse(TopDUContext::Empty);
+    QVERIFY(pragmaFile.waitForParsed());
+    QVERIFY(macroFile.waitForParsed());
+
+    DUChainReadLocker lock;
+    const auto pragmaTopContext = DUChain::self()->chainForDocument(pragmaFile.url());
+    const auto macroTopContext = DUChain::self()->chainForDocument(macroFile.url());
+    QVERIFY(pragmaTopContext);
+    QVERIFY(macroTopContext);
+
+    const auto pragmaProblem = findStaticAssistantProblem(DUChainUtils::allProblemsForContext(pragmaTopContext));
+    const auto macroProblem = findStaticAssistantProblem(DUChainUtils::allProblemsForContext(macroTopContext));
+    QVERIFY(pragmaProblem && macroProblem);
+    pragmaAssistant = pragmaProblem->solutionAssistant();
+    macroAssistant = macroProblem->solutionAssistant();
+    QVERIFY(pragmaAssistant && macroAssistant);
+
+    pragmaAssistant->actions()[0]->execute();
+    macroAssistant->actions()[1]->execute();
+
+    QCOMPARE(pragmaFile.fileContents(), pragmaExpected);
+    QCOMPARE(macroFile.fileContents(), macroExpected);
+
+    CodeRepresentation::setDiskChangesForbidden(true);
+}
+
+void TestAssistants::testHeaderGuardAssistant_data()
+{
+    QTest::addColumn<QString>("filename");
+    QTest::addColumn<QString>("code");
+    QTest::addColumn<QString>("pragmaExpected");
+    QTest::addColumn<QString>("macroExpected");
+
+    QTest::newRow("simple") << QStringLiteral("simpleheaderguard")
+        << QStringLiteral("int main()\n{\nreturn 0;\n}\n")
+        << QStringLiteral("#pragma once\n\nint main()\n{\nreturn 0;\n}\n")
+        << QStringLiteral(
+            "#ifndef SIMPLEHEADERGUARD_H_INCLUDED\n"
+            "#define SIMPLEHEADERGUARD_H_INCLUDED\n\n"
+            "int main()\n{\nreturn 0;\n}\n\n"
+            "#endif // SIMPLEHEADERGUARD_H_INCLUDED"
+        );
+
+    QTest::newRow("licensed") << QStringLiteral("licensed-headerguard")
+        << QStringLiteral("/* Copyright 3019 John Doe\n */\n// Some comment\n"
+                          "int main()\n{\nreturn 0;\n}\n")
+        << QStringLiteral("/* Copyright 3019 John Doe\n */\n// Some comment\n"
+                          "#pragma once\n\n"
+                          "int main()\n{\nreturn 0;\n}\n")
+        << QStringLiteral(
+            "/* Copyright 3019 John Doe\n */\n// Some comment\n"
+            "#ifndef LICENSED_HEADERGUARD_H_INCLUDED\n"
+            "#define LICENSED_HEADERGUARD_H_INCLUDED\n\n"
+            "int main()\n{\nreturn 0;\n}\n\n"
+            "#endif // LICENSED_HEADERGUARD_H_INCLUDED"
+        );
+
+    QTest::newRow("empty") << QStringLiteral("empty-file")
+        << QStringLiteral("")
+        << QStringLiteral("#pragma once\n\n")
+        << QStringLiteral("#ifndef EMPTY_FILE_H_INCLUDED\n"
+                          "#define EMPTY_FILE_H_INCLUDED\n\n\n"
+                          "#endif // EMPTY_FILE_H_INCLUDED"
+        );
+
+    QTest::newRow("no-trailinig-newline") << QStringLiteral("no-endline-file")
+        << QStringLiteral("int foo;")
+        << QStringLiteral("#pragma once\n\nint foo;")
+        << QStringLiteral("#ifndef NO_ENDLINE_FILE_H_INCLUDED\n"
+                            "#define NO_ENDLINE_FILE_H_INCLUDED\n\n"
+                            "int foo;\n"
+                            "#endif // NO_ENDLINE_FILE_H_INCLUDED"
+        );
+
+    QTest::newRow("whitespace-at-start") << QStringLiteral("whitespace-at-start")
+        << QStringLiteral("\nint foo;")
+        << QStringLiteral("#pragma once\n\n\nint foo;")
+        << QStringLiteral(
+            "#ifndef WHITESPACE_AT_START_H_INCLUDED\n"
+            "#define WHITESPACE_AT_START_H_INCLUDED\n\n"
+            "\nint foo;\n"
+            "#endif // WHITESPACE_AT_START_H_INCLUDED"
+        );
+}
