@@ -40,6 +40,8 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
+#include <qtcompat_p.h>
+
 using namespace KDevelop;
 namespace gh
 {
@@ -55,14 +57,14 @@ ProviderWidget::ProviderWidget(QWidget *parent)
     m_waiting->setAlignment(Qt::AlignCenter);
     m_waiting->hide();
 
-    ProviderModel *model = new ProviderModel(this);
+    auto *model = new ProviderModel(this);
     m_projects->setModel(model);
     m_projects->setEditTriggers(QAbstractItemView::NoEditTriggers);
     m_resource = new Resource(this, model);
     m_account = new Account(m_resource);
     connect(m_resource, &Resource::reposUpdated, m_waiting, &QLabel::hide);
 
-    QHBoxLayout *topLayout = new QHBoxLayout();
+    auto *topLayout = new QHBoxLayout();
     m_edit = new LineEdit(this);
     m_edit->setPlaceholderText(i18n("Search"));
     m_edit->setToolTip(i18n("You can press the Return key if you do not want to wait"));
@@ -71,7 +73,7 @@ ProviderWidget::ProviderWidget(QWidget *parent)
 
     m_combo = new QComboBox(this);
     m_combo->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Fixed);
-    connect(m_combo, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ProviderWidget::searchRepo);
+    connect(m_combo, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ProviderWidget::searchRepo);
     fillCombo();
     topLayout->addWidget(m_combo);
 
@@ -138,7 +140,7 @@ void ProviderWidget::projectIndexChanged(const QModelIndex &currentIndex)
 
 void ProviderWidget::showSettings()
 {
-    Dialog *dialog = new Dialog(this, m_account);
+    auto *dialog = new Dialog(this, m_account);
     connect(dialog, &Dialog::shouldUpdate, this, &ProviderWidget::fillCombo);
     dialog->show();
 }
@@ -163,6 +165,7 @@ void ProviderWidget::searchRepo()
     case 2: /* Known organization */
         text = m_combo->currentText();
         enabled = false;
+        Q_FALLTHROUGH();
     default:/* Looking for some organization's repo. */
         uri = QStringLiteral("/orgs/%1/repos").arg(text);
         break;
