@@ -68,7 +68,7 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
 {
     setWindowTitle(i18n("Output View"));
     setWindowIcon(tvdata->icon);
-    QVBoxLayout* layout = new QVBoxLayout(this);
+    auto* layout = new QVBoxLayout(this);
     layout->setMargin(0);
     if( data->type & KDevelop::IOutputView::MultipleView )
     {
@@ -112,7 +112,7 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
         addAction(m_focusOnSelect);
     }
 
-    QAction *separator = new QAction(this);
+    auto *separator = new QAction(this);
     separator->setSeparator(true);
     addAction(separator);
 
@@ -149,7 +149,7 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
 
     if( data->option & KDevelop::IOutputView::AddFilterAction )
     {
-        QAction *separator = new QAction(this);
+        auto *separator = new QAction(this);
         separator->setSeparator(true);
         addAction(separator);
 
@@ -184,14 +184,25 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
     connect( this, &OutputWidget::outputRemoved,
              data->plugin, &StandardOutputView::outputRemoved );
 
-    foreach( int id, data->outputdata.keys() )
-    {
+    for (auto it = data->outputdata.keyBegin(), end =data->outputdata.keyEnd(); it != end; ++it) {
+        int id = *it;
         changeModel( id );
         changeDelegate( id );
     }
     enableActions();
 }
 
+OutputWidget::~OutputWidget()
+{
+    // Disconnect our widget to prevent updateFilter() slot calling from parent's destructor,
+    // which leads to segfault since m_views hash will be destroyed before.
+    if (m_tabwidget) {
+        m_tabwidget->disconnect(this);
+    } else if (m_stackwidget) {
+        m_stackwidget->disconnect(this);
+    }
+}
+
 void OutputWidget::clearModel()
 {
     auto view = qobject_cast<QAbstractItemView*>(currentWidget());
@@ -230,8 +241,10 @@ void OutputWidget::setCurrentWidget( QTreeView* view )
 
 void OutputWidget::changeDelegate( int id )
 {
-    if( data->outputdata.contains( id ) && m_views.contains( id ) ) {
-        m_views.value(id)->setItemDelegate(data->outputdata.value(id)->delegate);
+    const auto viewIt = m_views.constFind(id);
+    const auto dataIt = data->outputdata.constFind(id);
+    if (dataIt != data->outputdata.constEnd() && viewIt != m_views.constEnd()) {
+        (*viewIt).view->setItemDelegate((*dataIt)->delegate);
     } else {
         addOutput(id);
     }
@@ -239,10 +252,10 @@ void OutputWidget::changeDelegate( int id )
 
 void OutputWidget::changeModel( int id )
 {
-    if( data->outputdata.contains( id ) && m_views.contains( id ) )
-    {
-        OutputData* od = data->outputdata.value(id);
-        m_views.value( id )->setModel(od->model);
+    const auto viewIt = m_views.constFind(id);
+    const auto dataIt = data->outputdata.constFind(id);
+    if (dataIt != data->outputdata.constEnd() && viewIt != m_views.constEnd()) {
+        (*viewIt).view->setModel((*dataIt)->model);
     }
     else
     {
@@ -252,44 +265,36 @@ void OutputWidget::changeModel( int id )
 
 void OutputWidget::removeOutput( int id )
 {
-    if( data->outputdata.contains( id ) && m_views.contains( id ) )
-    {
-        QTreeView* view = m_views.value(id);
+    const auto viewIt = m_views.constFind(id);
+    if (data->outputdata.contains(id) && (viewIt != m_views.constEnd())) {
+        auto view = viewIt->view;
         if( data->type & KDevelop::IOutputView::MultipleView || data->type & KDevelop::IOutputView::HistoryView )
         {
             if( data->type & KDevelop::IOutputView::MultipleView )
             {
                 int idx = m_tabwidget->indexOf( view );
-                if( idx != -1 )
+                if (idx != -1)
                 {
                     m_tabwidget->removeTab( idx );
-                    if( m_proxyModels.contains( id ) )
-                    {
-                        delete m_proxyModels.take( id );
-                        m_filters.remove( id );
-                    }
                 }
             } else
             {
                 int idx = m_stackwidget->indexOf( view );
-                if( idx != -1 && m_proxyModels.contains( id ) )
+                if (idx != -1)
                 {
-                    delete m_proxyModels.take( id );
-                    m_filters.remove( id );
+                    m_stackwidget->removeWidget(view);
                 }
-                m_stackwidget->removeWidget( view );
-            }
-            delete view;
-        } else
-        {
-            m_views.value( id )->setModel( nullptr );
-            m_views.value( id )->setItemDelegate( nullptr );
-            if( m_proxyModels.contains( 0 ) ) {
-                delete m_proxyModels.take( 0 );
-                m_filters.remove( 0 );
             }
+        } else {
+            // KDevelop::IOutputView::OneView case
+            // Do nothig here since our single view will be automatically removed from layout
+            // during it's destroy
         }
-        m_views.remove( id );
+
+        m_views.erase(viewIt);
+        // remove our view with proxy model which is view's child (see outputFilter() method).
+        delete view;
+
         emit outputRemoved( data->toolViewId, id );
     }
     enableActions();
@@ -300,9 +305,9 @@ void OutputWidget::closeActiveView()
     QWidget* widget = m_tabwidget->currentWidget();
     if( !widget )
         return;
-    foreach( int id, m_views.keys() )
-    {
-        if( m_views.value(id) == widget )
+    const auto ids = m_views.keys();
+    for (int id : ids) {
+        if (m_views.value(id).view == widget)
         {
             OutputData* od = data->outputdata.value(id);
             if( od->behaviour & KDevelop::IOutputView::AllowUserClose )
@@ -320,8 +325,9 @@ void OutputWidget::closeOtherViews()
     if (!widget)
         return;
 
-    foreach (int id, m_views.keys()) {
-        if (m_views.value(id) == widget) {
+    const auto ids = m_views.keys();
+    for (int id : ids) {
+        if (m_views.value(id).view == widget) {
             continue; // leave the active view open
         }
 
@@ -344,7 +350,7 @@ QWidget* OutputWidget::currentWidget() const
         widget = m_stackwidget->currentWidget();
     } else
     {
-        widget = m_views.begin().value();
+        widget = m_views.begin()->view;
     }
     return widget;
 }
@@ -356,13 +362,13 @@ KDevelop::IOutputViewModel *OutputWidget::outputViewModel() const
         return nullptr;
 
     QAbstractItemModel *absmodel = view->model();
-    KDevelop::IOutputViewModel *iface = dynamic_cast<KDevelop::IOutputViewModel*>(absmodel);
+    auto* iface = qobject_cast<KDevelop::IOutputViewModel*>(absmodel);
     if ( ! iface )
     {
         // try if it's a proxy model?
-        if ( QAbstractProxyModel* proxy = qobject_cast<QAbstractProxyModel*>(absmodel) )
+        if ( auto* proxy = qobject_cast<QAbstractProxyModel*>(absmodel) )
         {
-            iface = dynamic_cast<KDevelop::IOutputViewModel*>(proxy->sourceModel());
+            iface = qobject_cast<KDevelop::IOutputViewModel*>(proxy->sourceModel());
         }
     }
     return iface;
@@ -387,8 +393,9 @@ void OutputWidget::activateIndex(const QModelIndex &index, QAbstractItemView *vi
         return;
     QModelIndex sourceIndex = index;
     QModelIndex viewIndex = index;
-    int id = m_views.key(qobject_cast<QTreeView*>(view));
-    if( QAbstractProxyModel* proxy = m_proxyModels.value(id) ) {
+    auto fvIt = findFilteredView(view);
+    if (fvIt != m_views.end() && fvIt->proxyModel) {
+        auto proxy = fvIt->proxyModel;
         if ( index.model() == proxy ) {
             // index is from the proxy, map it to the source
             sourceIndex = proxy->mapToSource(index);
@@ -435,8 +442,9 @@ void OutputWidget::selectItem(SelectionMode selectionMode)
     eventuallyDoFocus();
 
     auto index = view->currentIndex();
-    int id = m_views.key(qobject_cast<QTreeView*>(view));
-    if (QAbstractProxyModel* proxy = m_proxyModels.value(id)) {
+    auto fvIt = findFilteredView(view);
+    if (fvIt != m_views.end() && fvIt->proxyModel) {
+        auto proxy = fvIt->proxyModel;
         if ( index.model() == proxy ) {
             // index is from the proxy, map it to the source
             index = proxy->mapToSource(index);
@@ -475,7 +483,7 @@ void OutputWidget::activate(const QModelIndex& index)
 QTreeView* OutputWidget::createListView(int id)
 {
     auto createHelper = [&]() -> QTreeView* {
-        KDevelop::FocusedTreeView* listview = new KDevelop::FocusedTreeView(this);
+        auto* listview = new KDevelop::FocusedTreeView(this);
         listview->setEditTriggers( QAbstractItemView::NoEditTriggers );
         listview->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn); //Always enable the scrollbar, so it doesn't flash around
         listview->setHeaderHidden(true);
@@ -494,8 +502,10 @@ QTreeView* OutputWidget::createListView(int id)
     };
 
     QTreeView* listview = nullptr;
-    if( !m_views.contains(id) )
-    {
+    const auto viewIt = m_views.constFind(id);
+    if (viewIt != m_views.constEnd()) {
+        listview = viewIt->view;
+    } else {
         bool newView = true;
 
         if( data->type & KDevelop::IOutputView::MultipleView || data->type & KDevelop::IOutputView::HistoryView )
@@ -505,35 +515,31 @@ QTreeView* OutputWidget::createListView(int id)
 
             if( data->type & KDevelop::IOutputView::MultipleView )
             {
-                m_tabwidget->addTab( listview, data->outputdata.value(id)->title );
+                m_tabwidget->addTab(listview, data->outputdata.value(id)->title);
             } else
             {
-                m_stackwidget->addWidget( listview );
-                m_stackwidget->setCurrentWidget( listview );
+                const int index = m_stackwidget->addWidget(listview);
+                m_stackwidget->setCurrentIndex(index);
             }
         } else
         {
             if( m_views.isEmpty() )
             {
                 listview = createHelper();
-
-                layout()->addWidget( listview );
+                layout()->addWidget(listview);
             } else
             {
-                listview = m_views.begin().value();
+                listview = m_views.begin().value().view;
                 newView = false;
             }
         }
-        m_views[id] = listview;
+        m_views[id].view = listview;
 
         changeModel( id );
         changeDelegate( id );
 
         if (newView)
             listview->scrollToBottom();
-    } else
-    {
-        listview = m_views.value(id);
     }
     enableActions();
     return listview;
@@ -541,18 +547,19 @@ QTreeView* OutputWidget::createListView(int id)
 
 void OutputWidget::raiseOutput(int id)
 {
-    if( m_views.contains(id) )
-    {
+    const auto viewIt = m_views.constFind(id);
+    if (viewIt != m_views.constEnd()) {
+        auto view = viewIt->view;
         if( data->type & KDevelop::IOutputView::MultipleView )
         {
-            int idx = m_tabwidget->indexOf( m_views.value(id) );
+            int idx = m_tabwidget->indexOf(view);
             if( idx >= 0 )
             {
                 m_tabwidget->setCurrentIndex( idx );
             }
         } else if( data->type & KDevelop::IOutputView::HistoryView )
         {
-            int idx = m_stackwidget->indexOf( m_views.value(id) );
+            int idx = m_stackwidget->indexOf(view);
             if( idx >= 0 )
             {
                 m_stackwidget->setCurrentIndex( idx );
@@ -597,7 +604,7 @@ void OutputWidget::scrollToIndex( const QModelIndex& idx )
     QWidget* w = currentWidget();
     if( !w )
         return;
-    QAbstractItemView *view = static_cast<QAbstractItemView*>(w);
+    auto *view = static_cast<QAbstractItemView*>(w);
     view->scrollTo( idx );
 }
 
@@ -606,7 +613,7 @@ void OutputWidget::copySelection()
     QWidget* widget = currentWidget();
     if( !widget )
         return;
-    QAbstractItemView *view = dynamic_cast<QAbstractItemView*>(widget);
+    auto* view = qobject_cast<QAbstractItemView*>(widget);
     if( !view )
         return;
 
@@ -622,7 +629,7 @@ void OutputWidget::copySelection()
 
 void OutputWidget::selectAll()
 {
-    if (QAbstractItemView *view = qobject_cast<QAbstractItemView*>(currentWidget()))
+    if (auto *view = qobject_cast<QAbstractItemView*>(currentWidget()))
         view->selectAll();
 }
 
@@ -641,34 +648,35 @@ int OutputWidget::currentOutputIndex()
 
 void OutputWidget::outputFilter(const QString& filter)
 {
-    QAbstractItemView *view = qobject_cast<QAbstractItemView*>(currentWidget());
+    auto *view = qobject_cast<QAbstractItemView*>(currentWidget());
     if( !view )
         return;
 
-    int id = m_views.key(qobject_cast<QTreeView*>(view));
+    auto fvIt = findFilteredView(view);
     auto proxyModel = qobject_cast<QSortFilterProxyModel*>(view->model());
     if( !proxyModel )
     {
-        proxyModel = new QSortFilterProxyModel(view->model());
+        // create new proxy model and make view it's parent. This allows us destroy view and
+        // it's model with "one shot" (see removeOutput() method).
+        fvIt->proxyModel = proxyModel = new QSortFilterProxyModel(view);
         proxyModel->setDynamicSortFilter(true);
         proxyModel->setSourceModel(view->model());
-        m_proxyModels.insert(id, proxyModel);
         view->setModel(proxyModel);
     }
     QRegExp regExp(filter, Qt::CaseInsensitive);
     proxyModel->setFilterRegExp(regExp);
-    m_filters[id] = filter;
+    fvIt->filter = filter;
 }
 
 void OutputWidget::updateFilter(int index)
 {
     QWidget *view = (data->type & KDevelop::IOutputView::MultipleView)
         ? m_tabwidget->widget(index) : m_stackwidget->widget(index);
-    int id = m_views.key(qobject_cast<QTreeView*>(view));
+    auto fvIt = findFilteredView(qobject_cast<QAbstractItemView*>(view));
 
-    if(m_filters.contains(id))
+    if (fvIt != m_views.end() && !fvIt->filter.isEmpty())
     {
-        m_filterInput->setText(m_filters[id]);
+        m_filterInput->setText(fvIt->filter);
     } else
     {
         m_filterInput->clear();
@@ -677,11 +685,21 @@ void OutputWidget::updateFilter(int index)
 
 void OutputWidget::setTitle(int outputId, const QString& title)
 {
-    QTreeView* view = m_views.value(outputId, nullptr);
-    if(view && (data->type & KDevelop::IOutputView::MultipleView)) {
-        int idx = m_tabwidget->indexOf(view);
+    auto fview = m_views.value(outputId, FilteredView{});
+    if (fview.view && (data->type & KDevelop::IOutputView::MultipleView)) {
+        const int idx = m_tabwidget->indexOf(fview.view);
         if (idx >= 0) {
             m_tabwidget->setTabText(idx, title);
         }
     }
 }
+
+QHash<int, OutputWidget::FilteredView>::iterator OutputWidget::findFilteredView(QAbstractItemView *view)
+{
+    for (auto it = m_views.begin(); it != m_views.end(); ++it) {
+        if (it->view == view) {
+            return it;
+        }
+    }
+    return m_views.end();
+}
